#!/usr/bin/env node

/**
 * Amaze testing suite
 * v.0.0.12
 *
 * https://npmjs.org/package/amaze-tdd
 *
 * Webdriver API commands and operations
 * http://seleniumhq.github.io/selenium/docs/api/javascript/
 * http://docs.seleniumhq.org/docs/03_webdriver.jsp#selenium-webdriver-api-commands-and-operations
 *
 * Mocha/Chai API
 * http://chaijs.com/api/bdd/
 */

var Mocha = require('../node_modules/mocha'),
    webdriver = require('../node_modules/selenium-webdriver'),
    chromedriver = require('../node_modules/chromedriver'),
    geckodriver = require('../node_modules/geckodriver'),
    iedriver = require('../node_modules/iedriver'),
    glob = require('glob'),
    args = process.argv,
    agent = args[args.length - 1],
    mocha,
    options;

// setup stuff per browser
if (agent === 'chrome') {
    var chrome = require('../node_modules/selenium-webdriver/chrome');
    options = new chrome.Options();
    options.addExtensions('selenium/crx/5.1.1_0.crx');
} else if (agent === 'firefox') {
    var firefox = require('../node_modules/selenium-webdriver/firefox');
    options = new firefox.Options();
} else if (agent === 'ie') {
    // IE
} else if (agent === 'phantomjs') {
    // phantomjs
} else {
    // error?
}

// instantiate mocha and set options
mocha = new Mocha({
    ui: 'tdd',
    reporter: 'spec',
    timeout: 10000
});

// create a global object for use in tests for cleanliness
var Amaze = {
    Webdriver: webdriver,
    By: webdriver.By,
    Until: webdriver.until,
    Chrome: chromedriver,
    Firefox: geckodriver,
    IE: iedriver,
    Mocha: mocha,
    Chai: require('chai'),
    Expect: require('chai').expect,
    Assert: require('chai').assert,
    Should: require('chai').should(),
    Agent: agent,
    Browser: new webdriver.Builder()
        .forBrowser(agent)
        // .withCapabilities(webdriver.Capabilities.chrome())  // not sure this is necessary
        .setChromeOptions(options)
        .build()
};

// collect tests
glob('./**/*-spec.js', function(err, files) {
    if (err) return console.log(err);

    for (var i = 0; i < files.length; i++) {
        Amaze.Mocha.addFile(files[i]);
    }

    // run the tests
    Amaze.Mocha.run(function(failures) {
        process.on('exit', function() {
            process.exit(failures);
        });
    });
});

module.exports = Amaze;