;(function(){

/**
 * Require the given path.
 *
 * @param {String} path
 * @return {Object} exports
 * @api public
 */

function require(path, parent, orig) {
  var resolved = require.resolve(path);

  // lookup failed
  if (null == resolved) {
    orig = orig || path;
    parent = parent || 'root';
    var err = new Error('Failed to require "' + orig + '" from "' + parent + '"');
    err.path = orig;
    err.parent = parent;
    err.require = true;
    throw err;
  }

  var module = require.modules[resolved];

  // perform real require()
  // by invoking the module's
  // registered function
  if (!module._resolving && !module.exports) {
    var mod = {};
    mod.exports = {};
    mod.client = mod.component = true;
    module._resolving = true;
    module.call(this, mod.exports, require.relative(resolved), mod);
    delete module._resolving;
    module.exports = mod.exports;
  }

  return module.exports;
}

/**
 * Registered modules.
 */

require.modules = {};

/**
 * Registered aliases.
 */

require.aliases = {};

/**
 * Resolve `path`.
 *
 * Lookup:
 *
 *   - PATH/index.js
 *   - PATH.js
 *   - PATH
 *
 * @param {String} path
 * @return {String} path or null
 * @api private
 */

require.resolve = function(path) {
  if (path.charAt(0) === '/') path = path.slice(1);

  var paths = [
    path,
    path + '.js',
    path + '.json',
    path + '/index.js',
    path + '/index.json'
  ];

  for (var i = 0; i < paths.length; i++) {
    var path = paths[i];
    if (require.modules.hasOwnProperty(path)) return path;
    if (require.aliases.hasOwnProperty(path)) return require.aliases[path];
  }
};

/**
 * Normalize `path` relative to the current path.
 *
 * @param {String} curr
 * @param {String} path
 * @return {String}
 * @api private
 */

require.normalize = function(curr, path) {
  var segs = [];

  if ('.' != path.charAt(0)) return path;

  curr = curr.split('/');
  path = path.split('/');

  for (var i = 0; i < path.length; ++i) {
    if ('..' == path[i]) {
      curr.pop();
    } else if ('.' != path[i] && '' != path[i]) {
      segs.push(path[i]);
    }
  }

  return curr.concat(segs).join('/');
};

/**
 * Register module at `path` with callback `definition`.
 *
 * @param {String} path
 * @param {Function} definition
 * @api private
 */

require.register = function(path, definition) {
  require.modules[path] = definition;
};

/**
 * Alias a module definition.
 *
 * @param {String} from
 * @param {String} to
 * @api private
 */

require.alias = function(from, to) {
  if (!require.modules.hasOwnProperty(from)) {
    throw new Error('Failed to alias "' + from + '", it does not exist');
  }
  require.aliases[to] = from;
};

/**
 * Return a require function relative to the `parent` path.
 *
 * @param {String} parent
 * @return {Function}
 * @api private
 */

require.relative = function(parent) {
  var p = require.normalize(parent, '..');

  /**
   * lastIndexOf helper.
   */

  function lastIndexOf(arr, obj) {
    var i = arr.length;
    while (i--) {
      if (arr[i] === obj) return i;
    }
    return -1;
  }

  /**
   * The relative require() itself.
   */

  function localRequire(path) {
    var resolved = localRequire.resolve(path);
    return require(resolved, parent, path);
  }

  /**
   * Resolve relative to the parent.
   */

  localRequire.resolve = function(path) {
    var c = path.charAt(0);
    if ('/' == c) return path.slice(1);
    if ('.' == c) return require.normalize(p, path);

    // resolve deps by returning
    // the dep in the nearest "deps"
    // directory
    var segs = parent.split('/');
    var i = lastIndexOf(segs, 'deps') + 1;
    if (!i) i = 0;
    path = segs.slice(0, i + 1).join('/') + '/deps/' + path;
    return path;
  };

  /**
   * Check if module is defined at `path`.
   */

  localRequire.exists = function(path) {
    return require.modules.hasOwnProperty(localRequire.resolve(path));
  };

  return localRequire;
};
require.register("rauchg-ms.js/index.js", function(exports, require, module){
/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} options
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options){
  options = options || {};
  if ('string' == typeof val) return parse(val);
  return options.long
    ? long(val)
    : short(val);
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  var match = /^((?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(str);
  if (!match) return;
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function short(ms) {
  if (ms >= d) return Math.round(ms / d) + 'd';
  if (ms >= h) return Math.round(ms / h) + 'h';
  if (ms >= m) return Math.round(ms / m) + 'm';
  if (ms >= s) return Math.round(ms / s) + 's';
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function long(ms) {
  return plural(ms, d, 'day')
    || plural(ms, h, 'hour')
    || plural(ms, m, 'minute')
    || plural(ms, s, 'second')
    || ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, n, name) {
  if (ms < n) return;
  if (ms < n * 1.5) return Math.floor(ms / n) + ' ' + name;
  return Math.ceil(ms / n) + ' ' + name + 's';
}

});
require.register("visionmedia-debug/browser.js", function(exports, require, module){

/**
 * This is the web browser implementation of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = require('./debug');
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;

/**
 * Use chrome.storage.local if we are in an app
 */

var storage;

if (typeof chrome !== 'undefined' && typeof chrome.storage !== 'undefined')
  storage = chrome.storage.local;
else
  storage = localstorage();

/**
 * Colors.
 */

exports.colors = [
  'lightseagreen',
  'forestgreen',
  'goldenrod',
  'dodgerblue',
  'darkorchid',
  'crimson'
];

/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */

function useColors() {
  // is webkit? http://stackoverflow.com/a/16459606/376773
  return ('WebkitAppearance' in document.documentElement.style) ||
    // is firebug? http://stackoverflow.com/a/398120/376773
    (window.console && (console.firebug || (console.exception && console.table))) ||
    // is firefox >= v31?
    // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
    (navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31);
}

/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

exports.formatters.j = function(v) {
  return JSON.stringify(v);
};


/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */

function formatArgs() {
  var args = arguments;
  var useColors = this.useColors;

  args[0] = (useColors ? '%c' : '')
    + this.namespace
    + (useColors ? ' %c' : ' ')
    + args[0]
    + (useColors ? '%c ' : ' ')
    + '+' + exports.humanize(this.diff);

  if (!useColors) return args;

  var c = 'color: ' + this.color;
  args = [args[0], c, 'color: inherit'].concat(Array.prototype.slice.call(args, 1));

  // the final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into
  var index = 0;
  var lastC = 0;
  args[0].replace(/%[a-z%]/g, function(match) {
    if ('%%' === match) return;
    index++;
    if ('%c' === match) {
      // we only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });

  args.splice(lastC, 0, c);
  return args;
}

/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */

function log() {
  // this hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return 'object' === typeof console
    && console.log
    && Function.prototype.apply.call(console.log, console, arguments);
}

/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */

function save(namespaces) {
  try {
    if (null == namespaces) {
      storage.removeItem('debug');
    } else {
      storage.debug = namespaces;
    }
  } catch(e) {}
}

/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */

function load() {
  var r;
  try {
    r = storage.debug;
  } catch(e) {}
  return r;
}

/**
 * Enable namespaces listed in `localStorage.debug` initially.
 */

exports.enable(load());

/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */

function localstorage(){
  try {
    return window.localStorage;
  } catch (e) {}
}

});
require.register("visionmedia-debug/debug.js", function(exports, require, module){

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = debug;
exports.coerce = coerce;
exports.disable = disable;
exports.enable = enable;
exports.enabled = enabled;
exports.humanize = require('ms');

/**
 * The currently active debug mode names, and names to skip.
 */

exports.names = [];
exports.skips = [];

/**
 * Map of special "%n" handling functions, for the debug "format" argument.
 *
 * Valid key names are a single, lowercased letter, i.e. "n".
 */

exports.formatters = {};

/**
 * Previously assigned color.
 */

var prevColor = 0;

/**
 * Previous log timestamp.
 */

var prevTime;

/**
 * Select a color.
 *
 * @return {Number}
 * @api private
 */

function selectColor() {
  return exports.colors[prevColor++ % exports.colors.length];
}

/**
 * Create a debugger with the given `namespace`.
 *
 * @param {String} namespace
 * @return {Function}
 * @api public
 */

function debug(namespace) {

  // define the `disabled` version
  function disabled() {
  }
  disabled.enabled = false;

  // define the `enabled` version
  function enabled() {

    var self = enabled;

    // set `diff` timestamp
    var curr = +new Date();
    var ms = curr - (prevTime || curr);
    self.diff = ms;
    self.prev = prevTime;
    self.curr = curr;
    prevTime = curr;

    // add the `color` if not set
    if (null == self.useColors) self.useColors = exports.useColors();
    if (null == self.color && self.useColors) self.color = selectColor();

    var args = Array.prototype.slice.call(arguments);

    args[0] = exports.coerce(args[0]);

    if ('string' !== typeof args[0]) {
      // anything else let's inspect with %o
      args = ['%o'].concat(args);
    }

    // apply any `formatters` transformations
    var index = 0;
    args[0] = args[0].replace(/%([a-z%])/g, function(match, format) {
      // if we encounter an escaped % then don't increase the array index
      if (match === '%%') return match;
      index++;
      var formatter = exports.formatters[format];
      if ('function' === typeof formatter) {
        var val = args[index];
        match = formatter.call(self, val);

        // now we need to remove `args[index]` since it's inlined in the `format`
        args.splice(index, 1);
        index--;
      }
      return match;
    });

    if ('function' === typeof exports.formatArgs) {
      args = exports.formatArgs.apply(self, args);
    }
    var logFn = enabled.log || exports.log || console.log.bind(console);
    logFn.apply(self, args);
  }
  enabled.enabled = true;

  var fn = exports.enabled(namespace) ? enabled : disabled;

  fn.namespace = namespace;

  return fn;
}

/**
 * Enables a debug mode by namespaces. This can include modes
 * separated by a colon and wildcards.
 *
 * @param {String} namespaces
 * @api public
 */

function enable(namespaces) {
  exports.save(namespaces);

  var split = (namespaces || '').split(/[\s,]+/);
  var len = split.length;

  for (var i = 0; i < len; i++) {
    if (!split[i]) continue; // ignore empty strings
    namespaces = split[i].replace(/\*/g, '.*?');
    if (namespaces[0] === '-') {
      exports.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
    } else {
      exports.names.push(new RegExp('^' + namespaces + '$'));
    }
  }
}

/**
 * Disable debug output.
 *
 * @api public
 */

function disable() {
  exports.enable('');
}

/**
 * Returns true if the given mode name is enabled, false otherwise.
 *
 * @param {String} name
 * @return {Boolean}
 * @api public
 */

function enabled(name) {
  var i, len;
  for (i = 0, len = exports.skips.length; i < len; i++) {
    if (exports.skips[i].test(name)) {
      return false;
    }
  }
  for (i = 0, len = exports.names.length; i < len; i++) {
    if (exports.names[i].test(name)) {
      return true;
    }
  }
  return false;
}

/**
 * Coerce `val`.
 *
 * @param {Mixed} val
 * @return {Mixed}
 * @api private
 */

function coerce(val) {
  if (val instanceof Error) return val.stack || val.message;
  return val;
}

});
require.register("component-emitter/index.js", function(exports, require, module){

/**
 * Expose `Emitter`.
 */

module.exports = Emitter;

/**
 * Initialize a new `Emitter`.
 *
 * @api public
 */

function Emitter(obj) {
  if (obj) return mixin(obj);
};

/**
 * Mixin the emitter properties.
 *
 * @param {Object} obj
 * @return {Object}
 * @api private
 */

function mixin(obj) {
  for (var key in Emitter.prototype) {
    obj[key] = Emitter.prototype[key];
  }
  return obj;
}

/**
 * Listen on the given `event` with `fn`.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.on =
Emitter.prototype.addEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};
  (this._callbacks['$' + event] = this._callbacks['$' + event] || [])
    .push(fn);
  return this;
};

/**
 * Adds an `event` listener that will be invoked a single
 * time then automatically removed.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.once = function(event, fn){
  function on() {
    this.off(event, on);
    fn.apply(this, arguments);
  }

  on.fn = fn;
  this.on(event, on);
  return this;
};

/**
 * Remove the given callback for `event` or all
 * registered callbacks.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.off =
Emitter.prototype.removeListener =
Emitter.prototype.removeAllListeners =
Emitter.prototype.removeEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};

  // all
  if (0 == arguments.length) {
    this._callbacks = {};
    return this;
  }

  // specific event
  var callbacks = this._callbacks['$' + event];
  if (!callbacks) return this;

  // remove all handlers
  if (1 == arguments.length) {
    delete this._callbacks['$' + event];
    return this;
  }

  // remove specific handler
  var cb;
  for (var i = 0; i < callbacks.length; i++) {
    cb = callbacks[i];
    if (cb === fn || cb.fn === fn) {
      callbacks.splice(i, 1);
      break;
    }
  }
  return this;
};

/**
 * Emit `event` with the given args.
 *
 * @param {String} event
 * @param {Mixed} ...
 * @return {Emitter}
 */

Emitter.prototype.emit = function(event){
  this._callbacks = this._callbacks || {};
  var args = [].slice.call(arguments, 1)
    , callbacks = this._callbacks['$' + event];

  if (callbacks) {
    callbacks = callbacks.slice(0);
    for (var i = 0, len = callbacks.length; i < len; ++i) {
      callbacks[i].apply(this, args);
    }
  }

  return this;
};

/**
 * Return array of callbacks for `event`.
 *
 * @param {String} event
 * @return {Array}
 * @api public
 */

Emitter.prototype.listeners = function(event){
  this._callbacks = this._callbacks || {};
  return this._callbacks['$' + event] || [];
};

/**
 * Check if this emitter has `event` handlers.
 *
 * @param {String} event
 * @return {Boolean}
 * @api public
 */

Emitter.prototype.hasListeners = function(event){
  return !! this.listeners(event).length;
};

});
require.register("stephenmathieson-crx-socket/index.js", function(exports, require, module){

exports.createClient = function (name) {
  return new exports.Client(name);
};

exports.createServer = function (name) {
  return new exports.Server(name);
};

exports.Client = require('./lib/client');
exports.Server = require('./lib/server');

});
require.register("stephenmathieson-crx-socket/lib/client.js", function(exports, require, module){

module.exports = Client;

/**
 * Create a `Client` of `name`.
 *
 * @api public
 * @param {String} name
 */

function Client(name) {
  if (!(this instanceof Client)) return new Client(name);
  this.name = name;
  this.port = chrome.runtime.connect({ name: name });
  this._onMessage = this.onMessage.bind(this);
  this.port.onMessage.addListener(this._onMessage);
  this.listeners = {};
}

/**
 * Emit a `name` message with the given `data`,
 * optionally invoking `fn(response)`.
 *
 * @api public
 * @param {String} name
 * @param {Mixed} data
 * @param {Function} [fn]
 * @return {Client} for chaining
 */

Client.prototype.emit = function (name, data, fn) {
  if ('function' == typeof data) fn = data, data = null;
  this.port.postMessage({
    client: this.name,
    name: name,
    data: data
  });
  // possibly leaky
  if (fn) this.once(name, fn);
  return this;
};

/**
 * Listen for the given `name` message with `fn`.
 *
 * @api public
 * @param {String} name
 * @param {Function} fn
 * @return {Client} for chaining
 */

Client.prototype.on = function (name, fn) {
  this.listeners[name] = this.listeners[name] || [];
  // avoid duplicate listeners
  if (~this.listeners[name].indexOf(fn)) return this;
  this.listeners[name].push(fn);
  return this;
};

/**
 * Listen for the given `name` message, but only
 * fire `fn` once.
 *
 * @api public
 * @param {String} name
 * @param {Function} fn
 * @return {Client} for chaining
 */

Client.prototype.once = function (name, fn) {
  var self = this;
  return this.on(name, function once(data) {
    fn.call(self, data);
    self.off(name, once);
  });
};

/**
 * Remove the given `fn` listener for `name` messages,
 * or all `name` listeners if `fn` is not provided.
 *
 * @api public
 * @param {String} name
 * @param {Function} fn
 * @return {Client} for chaining
 */

Client.prototype.off = function (name, fn) {
  var fns = this.listeners[name];
  if (!fns || !fns.length) return this;
  if (fn) {
    // remove specific listener
    var i = fns.indexOf(fn);
    if (~i) fns.splice(i, 1);
  } else {
    // remove *all* listeners
    fns.length = 0;
  }
  return this;
};

/**
 * Message recv callback.
 *
 * @api private
 * @param {Mixed} msg
 */

Client.prototype.onMessage = function (msg) {
  if (!msg.name) return;

  // copy array to handle `.once` removals, etc.
  var fns = (this.listeners[msg.name] || []).slice(0);
  for (var i = 0, l = fns.length; i < l; i++) {
    fns[i].call(this, msg.data);
  }
};

});
require.register("stephenmathieson-crx-socket/lib/server.js", function(exports, require, module){

var Emitter = require('emitter');

module.exports = Server;

/**
 * Create a `Server` of `name`.
 *
 * @api public
 * @param {String} name
 */

function Server(name) {
  if (!(this instanceof Server)) return new Server(name);
  Emitter.call(this);
  this.name = name;
  this._onConnection = this.onConnection.bind(this);
  this._onMessage = this.onMessage.bind(this);
  chrome.runtime.onConnect.addListener(this._onConnection);
  this.ports = [];
}

/**
 * Inherit `Emitter` prototype.
 */

Emitter(Server.prototype);

/**
 * Client connection callback.
 *
 * @api private
 * @param {Port} port
 */

Server.prototype.onConnection = function (port) {
  this.emit('connection', port);
  this.ports.push(port);
  port.onMessage.addListener(this._onMessage);
  port.onDisconnect.addListener(this.onDisconnect.bind(this, port));
};

/**
 * Client disconnect callback.
 *
 * @api private
 * @param {Port} port
 */

Server.prototype.onDisconnect = function (port) {
  var i = this.ports.indexOf(port);
  if (~i) {
    this.ports.splice(i, 1);
    this.emit('disconnect', port);
  }
};

/**
 * Message recv callback.
 *
 * @api private
 * @param {Object} msg
 */

Server.prototype.onMessage = function (msg) {
  this.emit('message', msg);

  if (!msg.client) {
    this.emit('error', new Error('A message requires a client'));
    return;
  }

  var port = null;
  for (var i = 0, l = this.ports.length; i < l; i++) {
    if (msg.client == this.ports[i].name) {
      port = this.ports[i];
      break;
    }
  }

  if (!port) {
    var err = new Error('No matching port for client: ' + msg.client);
    this.emit('error', err);
    return;
  }

  var res = new Response(msg, port);
  this.emit(msg.name, msg.data, res);
};

/**
 * Broadcast the given `data` to all connected clients.
 *
 * @api public
 * @param {Object|String} data
 * @return {Server} for chaining
 */

Server.prototype.broadcast = function (data) {
  if ('string' == typeof data) {
    data = { data: data, name: 'broadcast' };
  }
  this.ports.forEach(function (port) {
    var msg = {
      client: port.name,
      name: data.name,
      data: data.data
    };
    port.postMessage(msg);
  });
  return this;
};

/**
 * Simple client response wrapper.
 *
 * @api private
 * @param {Object} msg
 * @param {Port} port
 */

function Response(msg, port) {
  this.port = port;
  this.msg = {
    client: port.name,
    name: msg.name
  };
}

/**
 * Respond with the given `data`.
 *
 * @api private
 * @param {Mixed} data
 * @return {Response}
 */

Response.prototype.send = function (data) {
  this.msg.data = data;
  this.port.postMessage(this.msg);
  return this;
};

});
require.register("gjohnson-uuid/index.js", function(exports, require, module){

/**
 * Taken straight from jed's gist: https://gist.github.com/982883
 *
 * Returns a random v4 UUID of the form xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx,
 * where each x is replaced with a random hexadecimal digit from 0 to f, and
 * y is replaced with a random hexadecimal digit from 8 to b.
 */

module.exports = function uuid(a){
  return a           // if the placeholder was passed, return
    ? (              // a random number from 0 to 15
      a ^            // unless b is 8,
      Math.random()  // in which case
      * 16           // a random number from
      >> a/4         // 8 to 11
      ).toString(16) // in hexadecimal
    : (              // or otherwise a concatenated string:
      [1e7] +        // 10000000 +
      -1e3 +         // -1000 +
      -4e3 +         // -4000 +
      -8e3 +         // -80000000 +
      -1e11          // -100000000000,
      ).replace(     // replacing
        /[018]/g,    // zeroes, ones, and eights with
        uuid         // random hex digits
      )
};
});
require.register("content/index.js", function(exports, require, module){

/**
 * Module dependencies.
 */

'use strict';

var debug = require('debug')('content');
var Client = require('crx-socket').Client;
var uuid = require('uuid');

var CLIENT_ID = ['content', uuid()].join(':');
debug('client: %s', CLIENT_ID);

var client = new Client(CLIENT_ID);

client.emit('get server url', function (url) {
  debug('server URL: %s', url);

  client.emit('get overlays', location.href, function (obj) {
    if (!obj) {
      debug('no matching overlays');
      return;
    }

    debug('got overlays :)');

    // insert each chunk into its own script tag
    Object.keys(obj).forEach(function (key) {
      insert(obj[key], 'amaze-dev-extension-' + key);
    });
  });
});

/**
 * Insert a `<script />` tag containing the given `js`.
 *
 * @api private
 * @param {String} js
 * @param {String} id
 */

function insert(js, id) {
  var el = document.createElement('script');
  el.textContent = js;
  el.id = id;
  document.body.appendChild(el);
}

});






require.alias("content/index.js", "amaze-chrome-dev/deps/content/index.js");
require.alias("content/index.js", "amaze-chrome-dev/deps/content/index.js");
require.alias("content/index.js", "content/index.js");
require.alias("visionmedia-debug/browser.js", "content/deps/debug/browser.js");
require.alias("visionmedia-debug/debug.js", "content/deps/debug/debug.js");
require.alias("visionmedia-debug/browser.js", "content/deps/debug/index.js");
require.alias("rauchg-ms.js/index.js", "visionmedia-debug/deps/ms/index.js");

require.alias("visionmedia-debug/browser.js", "visionmedia-debug/index.js");
require.alias("stephenmathieson-crx-socket/index.js", "content/deps/crx-socket/index.js");
require.alias("stephenmathieson-crx-socket/lib/client.js", "content/deps/crx-socket/lib/client.js");
require.alias("stephenmathieson-crx-socket/lib/server.js", "content/deps/crx-socket/lib/server.js");
require.alias("stephenmathieson-crx-socket/index.js", "content/deps/crx-socket/index.js");
require.alias("component-emitter/index.js", "stephenmathieson-crx-socket/deps/emitter/index.js");

require.alias("stephenmathieson-crx-socket/index.js", "stephenmathieson-crx-socket/index.js");
require.alias("gjohnson-uuid/index.js", "content/deps/uuid/index.js");

require.alias("content/index.js", "content/index.js");
require("content");}());
